@@ -35,6 +35,8 @@ int esd_audio_open()
     if ( (esd_audio_format & ESD_MASK_FUNC) == ESD_RECORD )
         mode = O_RDWR;
 
+    mode |= O_NONBLOCK;
+
     /* open the sound device */
     device = esd_audio_device ? esd_audio_device : "/dev/dsp";
     if ((afd = open(device, mode, 0)) == -1)
@@ -43,6 +45,10 @@ int esd_audio_open()
         return( -2 );
     }
 
+    mode = fcntl(afd, F_GETFL);
+    mode &= ~O_NONBLOCK;
+    fcntl(afd, F_SETFL);
+
     /* TODO: check that this is allowable */
     /* set for full duplex operation, if recording */
 #if defined(SNDCTL_DSP_SETDUPLEX)
